@@ -1,4 +1,4 @@
-#                       Copyright 2020 Saad Mairaj
+#                       Copyright 2021 Saad Mairaj
 # 
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -19,19 +19,12 @@ looks and feels exactly like a native tkinter button can change its background
 and foreground colors.
 
 Read more about tkmacosx in detail on
-https://github.com/Saadmairaj/tkmacosx/tree/master/tkmacosx.
+https://github.com/Saadmairaj/tkmacosx#tkmacosx
 """
 
-__version__ = '0.1.4'
+__version__ = '0.1.6'
 
 from tkmacosx.basewidget import check_appearance, get_shade, delta
-from tkmacosx.variables import ColorVar, DictVar, SaveVar, demo_colorvar, demo_savevar
-from tkmacosx.widget import Button, CircleButton, SFrame, Marquee, demo_sframe, demo_button, demo_marquee
-from tkmacosx.colors import Hex, OrderedHex, all_colors, named_colors, hue_color
-from tkmacosx.colorscale import Colorscale, demo_colorscale, gradient
-
-if __name__ == "__main__":
-    demo_sframe()
-    demo_button()
-    demo_colorvar()
-    demo_colorscale()
+from tkmacosx.variables import ColorVar, DictVar, SaveVar
+from tkmacosx.widget import Button, CircleButton, SFrame, Marquee, Radiobutton
+from tkmacosx.colorscale import Colorscale, gradient, hex_to_rgb, check_light_dark
