@@ -1,4 +1,4 @@
-#                       Copyright 2020 Saad Mairaj
+#                       Copyright 2021 Saad Mairaj
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -12,37 +12,24 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import sys
 import random
-if sys.version_info.major == 2:
-    import ttk
-    import Tkinter as tk
-    import tkFont as font
-    from tkColorChooser import askcolor
-elif sys.version_info.major == 3:
-    from tkinter import ttk
-    import tkinter as tk
-    import tkinter.font as font
-    from tkinter.colorchooser import askcolor
+import tkinter as tk
 
-from tkmacosx.widget import *
-from tkmacosx.variables import *
-from tkmacosx.colorscale import Colorscale
-from tkmacosx.colors import Hex as C_dict, all_colors
+from tkinter import font
+from tkinter import ttk
+from tkinter.colorchooser import askcolor
 
-
-color_list = [list(i.values())[0].get('hex') for i in all_colors]
+from tkmacosx.widget import SFrame, Button
+from tkmacosx.variables import ColorVar
+from tkmacosx.colorscale import Colorscale, check_light_dark
 
 
 def grid(root, row, column):
     "Defines rows and columns if grid method is used"
-    if column:
-        for y in range(column):
-            tk.Grid.columnconfigure(root, y, weight=1)
-    if row:
-        for x in range(row):
-            tk.Grid.rowconfigure(root, x, weight=1)
-    return
+    for y in range(column):
+        tk.Grid.columnconfigure(root, y, weight=1)
+    for x in range(row):
+        tk.Grid.rowconfigure(root, x, weight=1)
 
 
 def sort_random_values(fn):
@@ -61,20 +48,25 @@ def choices(seq, k):
 
 @sort_random_values
 def get_random_colors(k=1):
-    return choices(color_list, k=k)
+    return ["#%06x" % random.randint(0, 0xFFFFFF) for n in range(k)]
 
 
 @sort_random_values
 def get_random_font(k=1):
-    def family(): return random.choice(font.families())
+    def family():
+        return random.choice(font.families())
 
-    def weight(): return random.choice(('bold', 'normal'))
+    def weight():
+        return random.choice(('bold', 'normal'))
 
-    def slant(): return random.choice(('italic', 'roman'))
+    def slant():
+        return random.choice(('italic', 'roman'))
 
-    def size(): return random.randrange(9, 30)
+    def size():
+        return random.randrange(15, 30)
 
-    def underline(): return random.choice((True, False))
+    def underline():
+        return random.choice((True, False))
 
     overstrike = underline
     return tuple(font.Font(family=family(), weight=weight(),
@@ -144,27 +136,28 @@ class Sample(tk.Tk):
         self.C1 = tk.StringVar(value='Select')
         self.L5 = tk.Label(self.sfr, text='From',
                            bg=self.main_color, font=('', 12))
-        self.L5.grid(row=5, column=1, sticky='nwe')
-        self.Om1 = tk.OptionMenu(self.sfr, self.C1, *C_dict.keys(),
-                                 command=self.change_active_color)
-        self.Om1.config(bg=self.main_color, width=15)
-        self.Om1.grid(row=6, column=1, sticky='s', pady=(0, 10))
-        for i in range(self.Om1['menu'].index('end')+1):
-            self.Om1['menu'].entryconfig(i, foreground=list(C_dict)[i])
-        self.C2 = tk.StringVar(value='Select')
+        self.L5.grid(row=5, column=1, sticky='ew')
+
         self.L6 = tk.Label(self.sfr, text='To',
                            bg=self.main_color, font=('', 12))
-        self.L6.grid(row=5, column=3, sticky='nwe')
-        self.Om2 = tk.OptionMenu(self.sfr, self.C2, *C_dict.keys(),
-                                 command=self.change_active_color)
-        self.Om2.config(bg=self.main_color, width=15)
-        self.Om2.grid(row=6, column=3, sticky='s', pady=(0, 10))
-        for i in range(self.Om2['menu'].index('end')+1):
-            self.Om2['menu'].entryconfig(i, foreground=list(C_dict)[i])
+        self.L6.grid(row=5, column=3, sticky='ew')
+        
+        button_container1 = tk.Frame(self.sfr, bg=self.main_color)
+        button_container1.grid(row=6, column=0, columnspan=5,
+                              sticky='ew', pady=10, padx=10)
+        button_container1.columnconfigure(0, weight=1)
+        button_container1.columnconfigure(1, weight=1)
+        self.Om1_b = Button(button_container1, text='Change Color',
+                         bg='#d0c0ea', borderless=1)
+        self.Om1_b.grid(row=0, column=0, padx=(0, 2), sticky='ew')
+        self.Om2_b = Button(button_container1, text='Change Color',
+                         bg="#d0c0ea", borderless=1)
+        self.Om2_b.grid(row=0, column=1, sticky='ew')
+        self.Om1_b['command'] = lambda: self.change_active_color(1)
+        self.Om2_b['command'] = lambda: self.change_active_color(2)
 
         # ------------ Background Color ------------
 
-        # ttk.Separator(self.sfr, orient='vertical').grid(row=6, column=2, columnspan=1, sticky='ew')
         self.L7 = tk.Label(self.sfr, text='2. Change Background color', bg=self.main_color,
                            font=('', 15, 'bold'))
         self.L7.grid(row=7, column=0, columnspan=5,
@@ -174,17 +167,22 @@ class Sample(tk.Tk):
         self.L8.grid(row=8, column=0, columnspan=5, sticky='new', pady=10)
 
         self.B2 = Button(self.sfr, text='Color me',
-                         font=('', 30,), pady=10, padx=10)
+                         font=('', 30,), pady=10)
         self.B2.grid(row=9, column=0, columnspan=5, sticky='', pady=20)
 
-        self.B3 = Button(self.sfr, text='Change Background Color',
+        button_container2 = tk.Frame(self.sfr, bg=self.main_color)
+        button_container2.grid(row=10, column=0, columnspan=5,
+                              sticky='ew', pady=10, padx=10)
+        button_container2.columnconfigure(0, weight=1)
+        button_container2.columnconfigure(1, weight=1)
+        self.B3 = Button(button_container2, text='Change Background Color',
                          bg='#d0c0ea', borderless=1)
         self.B3['command'] = lambda: self.B2.config(bg=askcolor()[1])
-        self.B3.grid(row=10, column=0, columnspan=5, sticky='w', pady=10, padx=10)
-        self.B4 = Button(self.sfr, text='Change Foreground Color',
+        self.B3.grid(row=0, column=0, padx=(0, 2))
+        self.B4 = Button(button_container2, text='Change Foreground Color',
                          bg="#d0c0ea", borderless=1)
         self.B4['command'] = lambda: self.B2.config(fg=askcolor()[1])
-        self.B4.grid(row=10, column=0, columnspan=5, sticky='e', pady=10, padx=10)
+        self.B4.grid(row=0, column=1)
 
         # ------------ Borderless ------------
 
@@ -254,24 +252,28 @@ class Sample(tk.Tk):
         self.B10 = Button(self.sfr, text='Button', borderless=1)
         self.B10.grid(row=25, columnspan=5, pady=20)
 
-        self.B11 =  Button(self.sfr, text='Change Style', borderless=1, fg='#21618C', 
-                           activebackground=('#B3B6B7', '#58D68D'), command=self.change_button_style)
+        self.B11 = Button(self.sfr, text='Change Style', borderless=1, fg='#21618C',
+                          activebackground=('#B3B6B7', '#58D68D'), command=self.change_button_style)
         self.B11.grid(row=26, columnspan=5, ipady=5)
 
         self.button_clicks = 1
-        self.Text1 = tk.Text(self.sfr, background=self.main_color, highlightthickness=0, 
+        self.Text1 = tk.Text(self.sfr, background=self.main_color, highlightthickness=0,
                              relief='sunken', height=20, bd=2, padx=10)
         self.Text1.grid(row=27, columnspan=5, pady=20, padx=20)
-        self.sfr._avoid_mousewheel((self.Text1, self.CS1, self.CS2, self.CS3, self.CS4))
+        self.sfr._avoid_mousewheel(
+            (self.Text1, self.CS1, self.CS2, self.CS3, self.CS4))
         self.change_button_style()
         self.update_idletasks()
 
-    def change_active_color(self, *ags):
-        c1 = self.C1.get() if not self.C1.get() == 'Select' else None
-        c2 = self.C2.get() if not self.C2.get() == 'Select' else None
-        self.Om1.config(bg=c1)
-        self.Om2.config(bg=c2)
-        self.B1['activebackground'] = (c1, c2)
+    def change_active_color(self, num):
+        hexcode = askcolor()[1]
+        if num == 1:
+            self.Om1_b['bg'] = self.Om1_b['text'] = hexcode
+            self.Om1_b['fg'] = check_light_dark(hexcode)
+        else:
+            self.Om2_b['bg'] = self.Om2_b['text'] = hexcode
+            self.Om2_b['fg'] = check_light_dark(hexcode)
+        self.B1['activebackground'] = (self.Om1_b['bg'], self.Om2_b['bg'])
 
     def change_borderless_state(self):
         if self.var1.get():
@@ -299,14 +301,15 @@ class Sample(tk.Tk):
         )
         self.B10.config(**cnf)
 
-        self.Text1.insert('end', '\n\nBUTTON STYLE %s\n\n'%self.button_clicks)
-        for k,v in cnf.items():
+        self.Text1.insert('end', '\n\nBUTTON STYLE %s\n\n' %
+                          self.button_clicks)
+        for k, v in cnf.items():
             if k == 'font':
                 self.Text1.insert('end', 'font:\n')
                 for i, j in v.config().items():
-                    self.Text1.insert('end', '\t%s\t\t= %s\n' %(i,j))
+                    self.Text1.insert('end', '\t%s\t\t= %s\n' % (i, j))
             else:
-                self.Text1.insert('end', '%s\t\t\t= %s\n' %(k,v))
+                self.Text1.insert('end', '%s\t\t\t= %s\n' % (k, v))
         self.Text1.see('end')
         self.Text1.insert('end', '\n\n'+'-'*40)
         self.button_clicks += 1
