@@ -1,4 +1,4 @@
-#                       Copyright 2020 Saad Mairaj
+#                       Copyright 2021 Saad Mairaj
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -14,27 +14,16 @@
 
 '''
 Newer style colorchoosers for tkinter module.
-
-Version: 0.1.4
 '''
 
-__version__ =  "0.1.4"
-
 import re
-import sys
-
-if sys.version_info.major == 2:  # For python 2.x
-    import Tkinter as _tk
-    from tkFont import Font
-    import tkFont as font
-elif sys.version_info.major == 3:  # For python 3.x
-    import tkinter as _tk
-    from tkinter import font
-    from tkinter.font import Font
-
 import colour
+import tkinter as _tk
 import tkmacosx.basewidget as tkb
 
+from tkinter import font
+from tkinter.font import Font
+
 
 HEX = 'hex'
 RGB = 'rgb'
@@ -68,6 +57,41 @@ def gradient(iteration):
     return _list
 
 
+def hex_to_rgb(hx, hsl=False):
+    """Converts a HEX code into RGB or HSL.
+    Args:
+        hx (str): Takes both short as well as long HEX codes.
+        hsl (bool): Converts the given HEX code into HSL value if True.
+    Return:
+        Tuple of length 3 consisting of either int or float values.
+    Raise:
+        ValueError: If given value is not a valid HEX code."""
+    if re.compile(r'#[a-fA-F0-9]{3}(?:[a-fA-F0-9]{3})?$').match(hx):
+        div = 255.0 if hsl else 0
+        if len(hx) <= 4:
+            return tuple(int(hx[i]*2, 16) / div if div else
+                         int(hx[i]*2, 16) for i in (1, 2, 3))
+        return tuple(int(hx[i:i+2], 16) / div if div else
+                     int(hx[i:i+2], 16) for i in (1, 3, 5))
+    raise ValueError(f'"{hx}" is not a valid HEX code.')
+
+
+def check_light_dark(value, intensity=110):
+    """Tells if the given RGB or HEX code is lighter or darker color.
+
+    Args:
+        value [str, tuple]: Give sequence of RBG values and hexcode.
+        intensity (int): The measurable amount of a brightness.
+    
+    Return:
+        str('white') / str('black')"""
+    if isinstance(value, str) and value.startswith('#'):
+        value = hex_to_rgb(value)
+    if (value[0]*0.299 + value[1]*0.587 + value[2]*0.114) > intensity:
+        return 'black'
+    return 'white'
+
+
 class Colorscale(tkb._Canvas):
     """
     ## Color Scale.
@@ -109,8 +133,8 @@ class Colorscale(tkb._Canvas):
         # Protected members of the class
         self._size = (0, 0)
         self._marker_color = 'black'
-        self._xy = int((self.winfo_reqwidth() if 'ver' in \
-                    self['orient'] else self.winfo_reqheight()) / 3)
+        self._xy = int((self.winfo_reqwidth() if 'ver' in
+                        self['orient'] else self.winfo_reqheight()) / 3)
 
         binds = [{'className': 'set_size', 'sequence': '<Configure>', 'func': self._set_size},
                  {'className': 'b1_on_motion', 'sequence': '<B1-Motion>',
@@ -139,44 +163,26 @@ class Colorscale(tkb._Canvas):
         showinfo, gradient lines) items."""
 
         def check_tag(tag):
-            """Internal function.\n
-            If `cmd="check"` and the tag does not exist then
-            the tag is created, but if `cmd="create"` and
-            safe_create=True this will delete the tag if exists
-            and creates a new tag  with same settings."""
-            if cmd == 'check':
-                c = False
-            elif cmd == 'create':
-                c = True
-            else:
-                raise ValueError(
-                    '%s is not a valid command! Takes -create, -check' % cmd)
-            cond1 = bool(not self.find('withtag', tag) or c)
-            cond2 = bool(tag not in kw.get('avoid', []))
-            if safe_create and cond1 and cond2:
-                self.delete(tag)
-            return cond1 and cond2
+            return self.check_tag(cmd, tag, safe_create, kw.get('avoid', []))
 
         ids = []
 
         if check_tag('gradient'):
             w, h = self.winfo_width(), self.winfo_height()
             iteration = w if 'ver' in self.cnf['orient'] else h
-            # iteration -=
-            if self.cnf.get('gradient', 'default') == 'default':
-                color_list = gradient(iteration)
-            elif isinstance(self.cnf.get('gradient'), (list, tuple)):
+            color_list = gradient(iteration)
+            if isinstance(self.cnf.get('gradient'), (list, tuple)):
                 c1 = colour.Color(self.cnf.get('gradient')[0])
                 c2 = colour.Color(self.cnf.get('gradient')[1])
                 color_list = c1.range_to(c2, iteration)
-            elif isinstance(self.cnf.get('gradient'), str):
+            elif isinstance(self.cnf.get('gradient'), str) \
+                    and self.cnf.get('gradient') != 'default':
                 c = colour.Color(self.cnf.get('gradient'))
                 color_list = c.range_to(c, iteration)
 
             for count, c in enumerate(color_list):
-                if self.cnf['orient'] == 'vertical':
-                    ags = (count, -1, count, h)
-                elif self.cnf['orient'] == 'horizontal':
+                ags = (count, -1, count, h)
+                if self.cnf['orient'] == 'horizontal':
                     ags = (-1, count, w, count)
                 ids.append(self._create('line', ags, {
                            'fill': c, 'tag': 'gradient'}))
@@ -187,32 +193,26 @@ class Colorscale(tkb._Canvas):
                                        (1, 1, self.winfo_width()-2,
                                         self.winfo_height()-2, 0))
             ids.append(self.rounded_rect(borderline_points, width=2,
-                                         outline='#81b3f4', tag='borderline', 
+                                         outline='#81b3f4', tag='borderline',
                                          style='arc'))
 
         if check_tag('marker'):
-            marker_points = kw.get('marker_points', (
-                self._xy if 'ver' in self.cnf['orient'] else 2,
-                2 if 'ver' in self.cnf['orient'] else self._xy,
-                5 if 'ver' in self.cnf['orient'] else self.winfo_width() - 4,
-                self.winfo_height() - 4 if 'ver' in self.cnf['orient'] else 5,
-                2))
+            _def_val = (2, self._xy, self.winfo_width()-4, 5, 2)
+            if self['orient'] == 'vertical':
+                _def_val = (self._xy, 2, 5, self.winfo_height()-4, 2)
+            marker_points = kw.get('marker_points', _def_val)
             ids.append(self.rounded_rect(marker_points, width=2,
-                                         outline=self._marker_color, 
+                                         outline=self._marker_color,
                                          tag="marker", style='arc'))
 
-        if check_tag('markerbg'):
+        if check_tag('markerbg') and kw.get('markerbg_points') is not None:
             markerbg_points = kw.get('markerbg_points')
             cnf = kw.get('markerbg_cnf')
-            if not markerbg_points:
-                return None
             ids.append(self._rounded(markerbg_points, **cnf))
 
-        if check_tag('info'):
+        if check_tag('info') and kw.get('info_points') is not None:
             info_points = kw.get('info_points')
             cnf = kw.get('info_cnf')
-            if not info_points:
-                return None
             ids.append(self._create('text', info_points, cnf))
 
         return ids
@@ -223,9 +223,25 @@ class Colorscale(tkb._Canvas):
 
     def _move_marker(self, evt, mw=None):
         """Internal function."""
+        spacer, spacbg = 35, 25
+
+        def diff_orient_val():
+            """Internal function."""
+            if self['orient'] == 'vertical':
+                return dict(
+                    evtx=mw,
+                    evty=10,
+                    _xy=evt.x,
+                )
+            return dict(
+                evtx=10,
+                evty=mw,
+                _xy=evt.y,
+            )
+
         if mw:
-            evt.x = mw if 'ver' in self.cnf['orient'] else 10
-            evt.y = 10 if 'ver' in self.cnf['orient'] else mw
+            evt.x = diff_orient_val()['evtx']
+            evt.y = diff_orient_val()['evty']
 
         self.after_cancel(getattr(self, '_remove_id', ' '))
         self._remove_id = self.after(self.cnf['showinfodelay'], self._release)
@@ -238,56 +254,49 @@ class Colorscale(tkb._Canvas):
             return
 
         if not mw:
-            self._xy = evt.x if 'ver' in self.cnf['orient'] else evt.y
+            self._xy = diff_orient_val()['_xy']
 
         c_id = self.find('overlapping', evt.x, evt.y, evt.x, evt.y)
-        hexcode = self.itemcget(c_id[0], 'fill')
+        text = hexcode = self.itemcget(c_id[0], 'fill')
         rgb = [int(i/65535.0*255.0) for i in self.winfo_rgb(hexcode)]
-        self._marker_color = 'black' if (
-            rgb[0]*0.299 + rgb[1]*0.587 + rgb[2]*0.114) > 110 else 'white'
+        self._marker_color = check_light_dark(rgb)
 
         self._configure(('itemconfigure', 'borderline'),
                         {'outline': hexcode}, None)
+        self._callback(hexcode)
 
         if self.cnf['value'] == "rgb":
             spacer, spacbg = 65, 55
             text = ' | '.join([v+':'+str(f)
                                for f, v in zip(rgb, ('R', 'G', 'B'))])
             self._callback(rgb)
-        elif self.cnf['value'] == "hex":
-            spacer, spacbg = 35, 25
-            text = hexcode
-            self._callback(hexcode)
 
-        ver_cond = evt.x < self.winfo_width() - (spacbg+spacer)\
-                        and self['orient'] == 'vertical'
-        hor_cond = evt.y < self.winfo_height() - (spacbg+spacer)\
-                         and self['orient'] == 'horizontal'
-        markerbg_points = info_points = ()
+        ver_cond = evt.x < self.winfo_width() - (spacbg+spacer) \
+            and self['orient'] == 'vertical'
+        hor_cond = evt.y < self.winfo_height() - (spacbg+spacer) \
+            and self['orient'] == 'horizontal'
+
+        markerbg_points, info_points = (), ()
 
         if bool(ver_cond or hor_cond) and self['showinfo']:
-            markerbg_points = (
-                evt.x+spacer - spacbg if 'ver' in self.cnf['orient'] else self.winfo_width()/2-6,
-                self.winfo_height()/2-6 if 'ver' in self.cnf['orient'] else evt.y+spacer-spacbg,
-                evt.x+spacer + spacbg if 'ver' in self.cnf['orient'] else self.winfo_width()/2+7,
-                self.winfo_height()/2+7 if 'ver' in self.cnf['orient'] else evt.y+spacer+spacbg,
-                6)
+            markerbg_points = (self.winfo_width()/2-6, evt.y+spacer - spacbg,
+                               self.winfo_width()/2+7, evt.y+spacer + spacbg, 6)
+            info_points = ((self.winfo_width()/2, evt.y+spacer))
 
-            info_points = (
-                (evt.x+spacer if 'ver' in self.cnf['orient'] else self.winfo_width()/2,
-                 self.winfo_height()/2 if 'ver' in self.cnf['orient'] else evt.y+spacer))
+            if self.cnf['orient'] == 'vertical':
+                markerbg_points = (evt.x+spacer - spacbg, self.winfo_height()/2-6,
+                                   evt.x+spacer + spacbg, self.winfo_height()/2+7, 6)
+                info_points = ((evt.x + spacer, self.winfo_height()/2))
 
         elif self['showinfo']:
-            markerbg_points = (
-                evt.x-spacer - spacbg if 'ver' in self.cnf['orient'] else self.winfo_width()/2-6,
-                self.winfo_height()/2-6 if 'ver' in self.cnf['orient'] else evt.y-spacer-spacbg,
-                evt.x-spacer +spacbg if 'ver' in self.cnf['orient'] else self.winfo_width()/2+7,
-                self.winfo_height()/2+7 if 'ver' in self.cnf['orient'] else evt.y-spacer+spacbg,
-                6)
+            markerbg_points = (self.winfo_width()/2-6, evt.y-spacer - spacbg,
+                               self.winfo_width()/2+7, evt.y-spacer + spacbg, 6)
+            info_points = ((self.winfo_width()/2, evt.y-spacer))
 
-            info_points = (
-                (evt.x-spacer if 'ver' in self.cnf['orient'] else self.winfo_width()/2,
-                 self.winfo_height()/2 if 'ver' in self.cnf['orient'] else evt.y-spacer))
+            if self.cnf['orient'] == 'vertical':
+                markerbg_points = (evt.x-spacer - spacbg, self.winfo_height()/2-6,
+                                   evt.x-spacer + spacbg, self.winfo_height()/2+7, 6)
+                info_points = ((evt.x - spacer, self.winfo_height()/2))
 
         markerbg_cnf = {'fill': self._marker_color, 'tag': 'markerbg'}
         info_cnf = {'angle': 0 if 'ver' in self.cnf['orient'] else 90,
@@ -296,7 +305,6 @@ class Colorscale(tkb._Canvas):
         self._create_items('create', safe_create=True, avoid=('gradient', 'borderline'),
                            info_points=info_points, markerbg_points=markerbg_points,
                            info_cnf=info_cnf, markerbg_cnf=markerbg_cnf)
-
         return True
 
     def _set_mousewheel(self, evt=None):
@@ -306,9 +314,9 @@ class Colorscale(tkb._Canvas):
         def on_mousewheel(evt=None):
             "Internal function."
             ver_cond = self._xy < self.winfo_width() \
-                        and self['orient'] == 'vertical'
+                and self['orient'] == 'vertical'
             hor_cond = self._xy < self.winfo_height() \
-                        and self['orient'] == 'horizontal'
+                and self['orient'] == 'horizontal'
             if tkb.delta(evt) <= -1 and (ver_cond or hor_cond):
                 self._xy += 1
                 if not self._move_marker(evt, mw=self._xy):
@@ -320,18 +328,18 @@ class Colorscale(tkb._Canvas):
 
         if self.cnf.get('mousewheel'):
             tkb._bind(self, className='mousewheel',
-                        sequence='<MouseWheel>', func=on_mousewheel)
+                      sequence='<MouseWheel>', func=on_mousewheel)
             tkb._bind(self, className='mousewheel_x11',
-                        sequence='<Button-4>', func=on_mousewheel)
+                      sequence='<Button-4>', func=on_mousewheel)
             tkb._bind(self, className='mousewheel_x11',
-                        sequence='<Button-5>', func=on_mousewheel)
+                      sequence='<Button-5>', func=on_mousewheel)
         else:
-            tkb._bind(self, className='mousewheel', 
-                        sequence='<MouseWheel>')
+            tkb._bind(self, className='mousewheel',
+                      sequence='<MouseWheel>')
             tkb._bind(self, className='mousewheel_x11',
-                        sequence='<Button-4>')
+                      sequence='<Button-4>')
             tkb._bind(self, className='mousewheel_x11',
-                        sequence='<Button-5>')
+                      sequence='<Button-5>')
 
     def _configure(self, cmd, cnf=None, kw=None):
         """Internal function."""
@@ -342,7 +350,7 @@ class Colorscale(tkb._Canvas):
         _return = tkb._Canvas._configure(self, cmd, None, kw1)
         if _tk._cnfmerge((cnf, kw)).get('gradient'):
             self._create_items('create', safe_create=True,
-                               avoid=('borderline', 'marker', 
+                               avoid=('borderline', 'marker',
                                       'markerbg', 'info'))
         self._set_mousewheel()
         if _return and isinstance(_return, dict):
@@ -364,38 +372,3 @@ class Colorscale(tkb._Canvas):
         """Destroy this widget."""
         self.after_cancel(getattr(self, '_remove_id', ' '))
         return tkb._Canvas.destroy(self)
-
-
-# ------------------------------------ #
-#           Testing and demo           #
-# ------------------------------------ #
-
-def demo_colorscale():
-    from tkmacosx.variables import ColorVar
-
-    root = _tk.Tk()
-    root.title("Tkinter Color Bar")
-    var = ColorVar()
-    _tk.Label(root, text="I am a Label, Hello! :-)",
-              bg=var).pack(padx=10, pady=10)
-    Colorscale(root, value='hex', variable=var, mousewheel=1,
-               gradient=('pink', 'purple')).pack(padx=10, pady=10)
-    Colorscale(root, value='hex', variable=var, mousewheel=1,
-               gradient=('green', 'yellow')).pack(padx=10, pady=10)
-    Colorscale(root, value='hex', variable=var, mousewheel=1,
-               gradient=('purple', 'cyan')).pack(padx=10, pady=10)
-    Colorscale(root, value='hex', variable=var, mousewheel=1,
-               gradient=('white', '#89ABE3')).pack(padx=10, pady=10)
-    Colorscale(root, value='hex', variable=var, mousewheel=1, 
-               gradient=('#5F4B8B', '#E69A8D'), orient='horizontal'
-               ).pack(padx=10, pady=10, side='left')
-    Colorscale(root, value='hex', variable=var, mousewheel=1, 
-               gradient=('#990011', '#FCF6F5'), orient='horizontal'
-               ).pack(padx=60, pady=10, side='left')
-    Colorscale(root, value='hex', variable=var, mousewheel=1, 
-               orient='horizontal').pack(padx=10, pady=10, side='left')
-    root.mainloop()
-
-
-if __name__ == "__main__":
-    demo_colorscale()
