@@ -1,4 +1,4 @@
-#                       Copyright 2020 Saad Mairaj
+#                       Copyright 2021 Saad Mairaj
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -12,11 +12,6 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import sys
-if sys.version_info.major == 2:
-    import Tkinter as _TK
-elif sys.version_info.major == 3:
-    import tkinter as _TK
 import tkmacosx.basewidget as tkb
 
 
@@ -124,6 +119,7 @@ class CircleButton(tkb.ButtonBase):
     root.mainloop()
     ```
     """
+
     def __init__(self, master=None, cnf={}, **kw):
         tkb.ButtonBase.__init__(self, 'circle', master, cnf, **kw)
 
@@ -196,56 +192,17 @@ class Marquee(tkb.MarqueeBase):
         self._animate()
 
 
-# ------------------ Testing ------------------
+class Radiobutton(tkb.RadiobuttonBase):
+    """Radiobutton widget which shows only one of several buttons in on-state."""
 
+    def __init__(self, master, cnf={}, **kw):
+        """Construct a radiobutton widget with the parent MASTER.
 
-def demo_button():
-    if sys.version_info.major == 2:
-        import ttk
-    elif sys.version_info.major == 3:
-        from tkinter import ttk
-    root = _TK.Tk()
-    root.title('Mac OSX Button Demo')
-    page_color = '#FFFFC6'
-    root.geometry('300x400')
-    root['bg'] = page_color
-    _TK.Label(root, text='Can you tell the difference?', font=(
-        '', 16, 'bold'), bg=page_color).pack(pady=(20, 5))
-    Button(root, text='Press Me', disabledbackground='red').pack(pady=(0, 5))
-    ttk.Button(root, text="Press Me").pack()
-    _TK.Label(root, text='Change Background Color', font=(
-        '', 16, 'bold'), bg=page_color).pack(pady=(20, 5))
-    Button(root, text='Press Me', bg='pink',
-           activebackground=('pink', 'blue')).pack()
-    _TK.Label(root, text='Blend In', font=('', 16, 'bold'),
-              bg=page_color).pack(pady=(20, 5))
-    Button(root, text='Press Me', bg='yellow', activebackground=(
-        'orange', 'lime'), borderless=1).pack()
-    _TK.Label(root, text='Change bordercolor', font=(
-        '', 16, 'bold'), bg=page_color).pack(pady=(20, 5))
-    Button(root, text='Press Me', bg='red', fg='white',
-           activebackground=('red', 'blue'), bordercolor='blue').pack()
-    root.mainloop()
-
-
-def demo_sframe():
-    root = _TK.Tk()
-    frame = SFrame(root, bg='pink')
-    frame.pack()
-    for i in range(50):
-        Button(frame, text='Button %s' % i, borderless=1).pack()
-    root.mainloop()
-
-
-def demo_marquee():
-    root = _TK.Tk()
-    marquee = Marquee(
-        root, text='This text will move from right to left if does not fit the window.')
-    marquee.pack()
-    root.mainloop()
-
-
-if __name__ == "__main__":
-    demo_sframe()
-    demo_button()
-    demo_marquee()
+        Valid resource names: activebackground, activeforeground, anchor,
+        background, bd, bg, bitmap, borderwidth, command, cursor,
+        disabledforeground, fg, font, foreground, height,
+        highlightbackground, highlightcolor, highlightthickness, image,
+        indicatoron, justify, padx, pady, relief, selectcolor, selectimage,
+        state, takefocus, text, textvariable, underline, value, variable,
+        width, wraplength."""
+        tkb.RadiobuttonBase.__init__(self, master=master, cnf=cnf, **kw)
